pytz: Timezone definitions for Python
=====================================

Description
-----------

World Timezone Definitions for Python
See https://pypi.org/project/pytz/


Special Update/Build Instructions
---------------------------------

The upstream tarball was repackaged after sanitizing the file
permissions with

$ chmod go-w
